Report

Trait Report 

pub trait Report {
    // Required methods
    fn die(&self) -> !;
    fn report(&self);
}
A trait for reporting errors to the user in a pretty format

Required Methods

fn die(&self) -> !

Prints the error to stderr and exits with a non-zero code

fn report(&self)

Prints the error to stderr

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Report for Error

Source

fn report(&self)

Source

fn die(&self) -> !

Implementors