Io

Struct Io 

pub struct Io { /* private fields */ }
IO Manager for wasm4pm (wpm) CLI

Implementations

Source

impl Io

pub fn new(verbose: bool) -> Self

Create a new IO manager

pub fn header<D: Display>(&self, text: D)

Print a stylized header

pub fn success<D: Display>(&self, text: D)

Print a success message

pub fn error<D: Display>(&self, text: D)

Print an error message to stderr

pub fn warning<D: Display>(&self, text: D)

Print a warning message

pub fn info<D: Display>(&self, text: D)

Print an info message only if verbose is enabled

pub fn read_file<P: AsRef<Path>>(&self, path: P) -> Result<String>

Read a file to string with consistent error wrapping

pub fn write_file<P: AsRef<Path>>(&self, path: P, content: &str) -> Result<()>

Write content to a file with consistent error wrapping